@@ -59,11 +59,12 @@ async def create_queues(queues, channel):
         )
         await dlq.bind(dlx_name, routing_key='#')
 
-        q_args = {
-            **{"x-queue-type": queue.get("type", "quorum")},
-            **{"x-dead-letter-exchange": queue.get('x-dead-letter-exchange', dlx_name)},
-            **queue.get("arguments", {})
-        }
+        if queue.get('x-dead-letter-exchange', dlx_name):
+            q_args = {
+                **q_args,
+                **{"x-dead-letter-exchange": queue.get('x-dead-letter-exchange', dlx_name)}
+            }
+
         q_conns[queue['name']] = await channel.declare_queue(
             queue['name'],
             arguments={**q_args},
